@@ -3,9 +3,18 @@ context("trelliscope plotting functions")
 test_that("trelliPlots check the correct inputs", {
   testthat::skip_on_cran()
   # Quick trelliscope function check for future changes
-  # file_coverage(c("./R/as.trelliData.R", "./R/summary_trelliData.R", "./R/trelliPlots.R"), 
-  #               c("./tests/testthat/test_as_trelliData_edata.R", "./tests/testthat/test_as_trelliData.R", "./tests/testthat/test_as_trelliData_summary.R", "./tests/testthat/test_trelliPlots.R")) %>% 
-  #     report()
+  #file_coverage(c("~/Git_Repos/pmartR/R/as.trelliData.R", 
+  #                "~/Git_Repos/pmartR/R/summary_trelliData.R",
+  #                "~/Git_Repos/pmartR/R/trelliPlots.R",
+  #                "~/Git_Repos/pmartR/R/trelliPlots_seqData.R",
+  #),
+  #c("~/Git_Repos/pmartR/tests/testthat/test_as_trelliData_edata.R", 
+  #  "~/Git_Repos/pmartR/tests/testthat/test_as_trelliData.R",
+  #  "~/Git_Repos/pmartR/tests/testthat/test_trelli_pvalue_filter.R",
+  #  "~/Git_Repos/pmartR/tests/testthat/test_as_trelliData_summary.R",
+  #  "~/Git_Repos/pmartR/tests/testthat/test_trelliPlots.R",
+  #  "~/Git_Repos/pmartR/tests/testthat/test_trelliPlots_seqData.R")
+  #) %>% report()
   
   # Load: lipid expression data-------------------------------------------------
 
@@ -54,11 +63,28 @@ test_that("trelliPlots check the correct inputs", {
     p_value_anova = 0.7,
     fold_change = NaN
   )
-  expect_null(pmartR:::determine_significance(ds_test, 0.05))
-
+  expect_null(pmartR:::determine_significance(ds_test, 0.05, is_seq = FALSE))
+  
+  # Load RNA-seq data for testing-----------------------------------------------
+  
+  load(system.file('testdata',
+                   'little_seqdata.RData',
+                   package = 'pmartR'
+  ))
+  
+  emeta <- data.frame("ID_REF" = edata$ID_REF, "Classification" = paste("Class", rep(1:200, 6)))
+  seqData_omics <- as.seqData(e_data = edata, f_data = fdata, edata_cname = "ID_REF", fdata_cname = "Samples", e_meta = emeta, emeta_cname = "Classification")
+  seqData_omics <- group_designation(seqData_omics, main_effects = "Tissue")
+  seqData_omics <- applyFilt(filter_object = total_count_filter(omicsData = seqData_omics), omicsData = seqData_omics, min_count = 15)
+  seqData_stat <- diffexp_seq(omicsData = seqData_omics, method = "voom")
+  seqTrelli1 <- as.trelliData.edata(e_data = edata, edata_cname = "ID_REF", omics_type = "seqData")
+  seqTrelli2 <- as.trelliData(omicsData = seqData_omics)
+  seqTrelli3 <- as.trelliData(statRes = seqData_stat)
+  seqTrelli4 <- as.trelliData(omicsData = seqData_omics, statRes = seqData_stat)
+  
   # Test: trelli plotting functions---------------------------------------------
 
-  ## trelli_abundance_boxplot
+  ## trelli_abundance_boxplot---------------------------------------------------
 
   # The object must be a trelliData object
   expect_error(
@@ -126,6 +152,22 @@ test_that("trelliPlots check the correct inputs", {
     "single_plot must be a TRUE or FALSE."
   )
 
+  # Expect a message that median and cv abundance have been removed
+  suppressWarnings({
+    expect_message(
+      mtrelliData2 %>% trelli_panel_by("Metabolite") %>% trelli_abundance_boxplot(test_mode = TRUE, test_example = 1, cognostics = c("median abundance", "cv abundance")),
+      "'median abundance' and 'cv abundance' are not permitted when groups have been specified."
+    )
+  })
+  
+  # Expect a message that anova p-value and fold change have been removed 
+  suppressWarnings({
+    expect_message(
+      mtrelliData4 %>% trelli_panel_by("MClass") %>% trelli_abundance_boxplot(test_mode = TRUE, test_example = 1, cognostics = c("anova p-value", "fold change")),
+      "Please panel by Metabolite to get 'anova p-value' and 'fold change' as cognostics in the trelliscope display."
+    )    
+  })
+  
   # Blank biomolecules should be removed, and if no data, an error produced
   blankExample <- mtrelliData1 %>% trelli_panel_by("Metabolite")
   blankExample$trelliData.omics <- blankExample$trelliData.omics[1, ]
@@ -186,8 +228,44 @@ test_that("trelliPlots check the correct inputs", {
       cognostics = NULL
     ))
   expect_true(file.exists(file.path(testFolder, "BoxAbundanceTest3")))
+  
+  # Build a trelliscope that panels by MClass
+  suppressWarnings(mtrelliData5 %>% trelli_panel_by("MClass") %>%
+                     trelli_abundance_boxplot(
+                       path = file.path(testFolder, "BoxAbundanceTest4"),
+                       test_mode = TRUE,
+                       test_example = 1,
+                       cognostics = "count"
+                     ))
+  expect_true(file.exists(file.path(testFolder, "BoxAbundanceTest4")))
+  
+  # Build a trelliscope that returns anova p-value and fold change only
+  suppressWarnings(mtrelliData5 %>% trelli_panel_by("Metabolite") %>%
+                     trelli_abundance_boxplot(
+                       path = file.path(testFolder, "BoxAbundanceTest5"),
+                       test_mode = TRUE,
+                       test_example = 1,
+                       cognostics = c("anova p-value", "fold change")
+                     ))
+  expect_true(file.exists(file.path(testFolder, "BoxAbundanceTest5")))
+  
+  # Build a trelliscope that returns anova p-value, fold change, and count
+  suppressWarnings(mtrelliData5 %>% trelli_panel_by("Metabolite") %>%
+                     trelli_abundance_boxplot(
+                       path = file.path(testFolder, "BoxAbundanceTest6"),
+                       test_mode = TRUE,
+                       test_example = 1,
+                       cognostics = c("count", "anova p-value", "fold change")
+                     ))
+  expect_true(file.exists(file.path(testFolder, "BoxAbundanceTest6")))
+  
+  # Seq data is not allowed for this dataset
+  expect_error(
+    seqTrelli1 %>% trelli_panel_by("ID_REF") %>% trelli_abundance_boxplot(),
+    "seqData is not permitted for this plotting function. Use trelli_rnaseq_boxplot instead."
+  )
 
-  ## trelli_abundance_histogram
+  ## trelli_abundance_histogram-------------------------------------------------
 
   # trelliData must be grouped by edata_cname
   expect_error(
@@ -201,11 +279,11 @@ test_that("trelliPlots check the correct inputs", {
     trelli_abundance_histogram(single_plot = TRUE)
   expect_true(inherits(abun_histplot, "ggplot"))
   
-  
+
   # Test that trelliscope builds when passed cognostic doesn't exist  
   suppressWarnings(mtrelliData1 %>% trelli_panel_by("Metabolite") %>% 
-    trelli_abundance_histogram(path = file.path(testFolder, "HistAbundanceTest1"),
-                               test_mode = TRUE, 
+     trelli_abundance_histogram(path = file.path(testFolder, "HistAbundanceTest1"),
+                                test_mode = TRUE, 
                                test_example = 2,
                                ggplot_params = "xlab('')",
                                cognostics = c("sample count", "cv abundance"),
@@ -229,8 +307,14 @@ test_that("trelliPlots check the correct inputs", {
       test_example = 3
     ))
   expect_true(file.exists(file.path(testFolder, "HistAbundanceTest3")))
-
-  ## trelli_abundance_heatmap
+  
+  # Seq data is not allowed for this dataset
+  expect_error(
+    seqTrelli1 %>% trelli_panel_by("ID_REF") %>% trelli_abundance_histogram(),
+    "seqData is not permitted for this plotting function. Use trelli_rnaseq_histogram instead."
+  )
+  
+  ## trelli_abundance_heatmap---------------------------------------------------
 
   # Test that the data has been grouped by an emeta column
   expect_error(
@@ -260,14 +344,31 @@ test_that("trelliPlots check the correct inputs", {
   suppressWarnings(nogroup %>%
     trelli_abundance_heatmap(path = file.path(testFolder, "HmAbundanceTest2")))
   expect_true(file.exists(file.path(testFolder, "HmAbundanceTest2")))
-
-  ## trelli_missingness_bar
+  
+  # Seq data is not allowed for this dataset
+  expect_error(
+    seqTrelli4 %>% trelli_panel_by("Classification") %>% trelli_abundance_heatmap(),
+    "seqData is not permitted for this plotting function. Use trelli_rnaseq_heatmap instead."
+  )
+  
+  ## trelli_missingness_bar-----------------------------------------------------
 
   # Trigger proportion check warning with something outrageous
   expect_error(
     mtrelliData3 %>% trelli_panel_by("Metabolite") %>% trelli_missingness_bar(proportion = "cantelope"),
     "proportion must be a TRUE or FALSE."
   )
+  
+  # Expect message if no p-values are provided 
+  expect_message(
+    mtrelliData1 %>% trelli_panel_by("Metabolite") %>% trelli_missingness_bar(cognostics = "g-test p-value", test_mode = T, test_example = 1)
+  )
+  
+  # Expect message if paneled by class
+  expect_message(
+    mtrelliData5 %>% trelli_panel_by("MClass") %>% trelli_missingness_bar(cognostics = "g-test p-value", test_mode = T, test_example = 1),
+    "'g-test p-value' can only be included if the data has been paneled by the biomolecule column 'edata_cname'"
+  )
 
   # Test trelliscope builds with all cognostics
   suppressWarnings(mtrelliData1 %>% trelli_panel_by("Metabolite") %>% 
@@ -286,15 +387,41 @@ test_that("trelliPlots check the correct inputs", {
                                             test_mode = TRUE, 
                                             test_example = 2,
                                             proportion = FALSE,
-                                            cognostics = "total count")
+                                            cognostics = c("g-test p-value", "total count"))
   )
   expect_true(file.exists(file.path(testFolder, "MissingTest2")))
+  
+  # Test trelliscope with paneling by a class
+  suppressWarnings(mtrelliData4 %>% trelli_panel_by("MClass") %>% 
+                     trelli_missingness_bar(path = file.path(testFolder, "MissingTest3"),
+                                            test_mode = TRUE, 
+                                            test_example = 2,
+                                            proportion = FALSE,
+                                            cognostics = "observed count")
+  )
+  expect_true(file.exists(file.path(testFolder, "MissingTest3")))
+  
+  # Test trelliscope with just a statRes object 
+  suppressWarnings(mtrelliData4 %>% trelli_panel_by("Metabolite") %>% 
+                     trelli_missingness_bar(path = file.path(testFolder, "MissingTest4"),
+                                            test_mode = TRUE, 
+                                            test_example = 2,
+                                            proportion = FALSE,
+                                            cognostics = c("g-test p-value"))
+  )
+  expect_true(file.exists(file.path(testFolder, "MissingTest4")))
 
   # Build a single plot
   miss_plot <- singlePlot %>% trelli_missingness_bar(single_plot = TRUE)
   expect_true(inherits(miss_plot, "ggplot"))
+  
+  # Seq data is not allowed for this dataset
+  expect_error(
+    seqTrelli1 %>% trelli_panel_by("ID_REF") %>% trelli_missingness_bar(),
+    "seqData is not permitted for this plotting function. Use trelli_rnaseq_nonzero_bar instead."
+  )
 
-  ## trelli_foldchange_bar
+  ## trelli_foldchange_bar------------------------------------------------------
 
   # statRes data is required for this function
   expect_error(
@@ -337,7 +464,7 @@ test_that("trelliPlots check the correct inputs", {
   suppressWarnings(singleStatPlot %>%
      trelli_foldchange_bar(path = file.path(testFolder, "barFoldChangeTest1"),
                            ggplot_params = "ylab('')",
-                           cognostics = "anova p-value",
+                           cognostics = "p-value",
                            interactive = TRUE)
   )
   expect_true(file.exists(file.path(testFolder, "barFoldChangeTest1")))
@@ -370,8 +497,17 @@ test_that("trelliPlots check the correct inputs", {
                                            p_value_thresh = 0,
                                            single_plot = TRUE)
   expect_true(inherits(fc_barplot, "ggplot"))
+  
+  # Generate a trelliscope with seq data 
+  suppressWarnings(seqTrelli3 %>% trelli_panel_by("ID_REF") %>% 
+                     trelli_foldchange_bar(path = file.path(testFolder, "barFoldChangeTest4"),
+                                           test_mode = TRUE, 
+                                           test_example = 2,
+                                           cognostics = "p-value")
+  )
+  expect_true(file.exists(file.path(testFolder, "barFoldChangeTest4")))
 
-  ## trelli_foldchange_boxplot
+  ## trelli_foldchange_boxplot--------------------------------------------------
 
   # Data must be grouped by an e_meta column
   expect_error(
@@ -406,12 +542,30 @@ test_that("trelliPlots check the correct inputs", {
                                                include_points = TRUE)
   )
   expect_true(file.exists(file.path(testFolder, "boxFoldChangeTest2")))
+  
+  # Add RNA-seq example
+  suppressWarnings(seqTrelli4 %>% trelli_panel_by("Classification") %>%
+                     trelli_foldchange_boxplot(path = file.path(testFolder, "boxFoldChangeTest3"),
+                                               test_mode = T,
+                                               test_example = 1)
+  )
+  expect_true(file.exists(file.path(testFolder, "boxFoldChangeTest3")))
+  
+  # Add RNA-seq example wit no p-value threshold
+  suppressWarnings(seqTrelli4 %>% trelli_panel_by("Classification") %>%
+                     trelli_foldchange_boxplot(path = file.path(testFolder, "boxFoldChangeTest4"),
+                                               test_mode = T,
+                                               test_example = 1,
+                                               p_value_thresh = 0)
+  )
+  expect_true(file.exists(file.path(testFolder, "boxFoldChangeTest4")))
+  
 
   # Generate a single plot
   fc_boxplot <- singleEmetaPlot %>% trelli_foldchange_boxplot(single_plot = TRUE)
   expect_true(inherits(fc_boxplot, "ggplot"))
 
-  ## trelli_foldchange_volcano
+  ## trelli_foldchange_volcano--------------------------------------------------
   
   # Data must be grouped by an e_meta column
   expect_error(
@@ -442,12 +596,41 @@ test_that("trelliPlots check the correct inputs", {
                                                p_value_thresh = 0)
   )
   expect_true(file.exists(file.path(testFolder, "volFoldChangeTest2")))
+  
+  # Add RNA-seq example
+  suppressWarnings(seqTrelli4 %>% trelli_panel_by("Classification") %>%
+                     trelli_foldchange_volcano(path = file.path(testFolder, "volFoldChangeTest3"),
+                                               test_mode = T,
+                                               test_example = 1)
+  )
+  expect_true(file.exists(file.path(testFolder, "volFoldChangeTest3")))
+  
+  # Add RNA-seq example
+  suppressWarnings(seqTrelli4 %>% trelli_panel_by("Classification") %>%
+                     trelli_foldchange_volcano(path = file.path(testFolder, "volFoldChangeTest4"),
+                                               test_mode = T,
+                                               test_example = 1,
+                                               p_value_thresh = 0)
+  )
+  expect_true(file.exists(file.path(testFolder, "volFoldChangeTest4")))
 
   # Test the creation of a single plot
   fc_volcano <- singleEmetaPlot %>% trelli_foldchange_volcano(single_plot = TRUE, p_value_test = NULL, comparison = "Mock_vs_InfectionA")
   expect_true(inherits(fc_volcano, "ggplot"))
+  
+  # Expect error if trying to return a single plot without selecting a comparison
+  expect_error(
+    mtrelliData4 %>% trelli_panel_by("MClass") %>% trelli_foldchange_volcano(single_plot = T),
+    "single_plot will only work if 1 comparison has been selected."
+  )
+  
+  # Expect error if comparison is not a string
+  expect_error(
+    mtrelliData4 %>% trelli_panel_by("MClass") %>% trelli_foldchange_volcano(single_plot = T, comparison = 2),
+    "comparison must be a string."
+  )
 
-  ## trelli_foldchange_heatmap
+  ## trelli_foldchange_heatmap--------------------------------------------------
 
   # Data must be grouped by an e_meta column
   expect_error(
@@ -463,13 +646,22 @@ test_that("trelliPlots check the correct inputs", {
       test_mode = TRUE,
       test_example = 2,
       interactive = TRUE
-    ))
+  ))
   expect_true(file.exists(file.path(testFolder, "hmFoldChangeTest1")))
 
   # Generate the fold change heatmap trelliscope with smaller dataset
   suppressWarnings(singleEmetaPlot %>%
     trelli_foldchange_heatmap(path = file.path(testFolder, "hmFoldChangeTest2"), ))
   expect_true(file.exists(file.path(testFolder, "hmFoldChangeTest2")))
+  
+  # Add RNA-seq example
+  suppressWarnings(seqTrelli4 %>% trelli_panel_by("Classification") %>%
+                     trelli_foldchange_heatmap(path = file.path(testFolder, "hmFoldChangeTest3"),
+                                               test_mode = T,
+                                               p_value_thresh = 0,
+                                               test_example = 1)
+  )
+  expect_true(file.exists(file.path(testFolder, "hmFoldChangeTest3")))
 
   # Generate a single plot
   fc_heatmap <- singleEmetaPlot %>% trelli_foldchange_heatmap(single_plot = TRUE)
